pilas.utils

Package pilas :: Module utils |
[hide private]
[frames] | no frames]

# Module utils

source code

Functions | [hide private]
es_interpolacion(an_object) Indica si un objeto se comportará como una interpolación. | source code
obtener_ruta_al_recurso(ruta) Busca la ruta a un archivo de recursos. | source code
esta_en_sesion_interactiva() Indica si pilas se ha ejecutado desde una consola interactiva de python. | source code
distancia(a, b) Retorna la distancia entre dos numeros. | source code
distancia_entre_dos_puntos((x1, y1), (x2, y2)) Retorna la distancia entre dos puntos en dos dimensiones. | source code
distancia_entre_dos_actores(a, b) Retorna la distancia en pixels entre dos actores. | source code
actor_mas_cercano_al_actor(actor) Retorna el actor de la escena que esté mas cercano a otro indicado por parámetro. | source code
colisionan(a, b) Retorna True si dos actores estan en contacto. | source code
interpolable(f) Decorador que se aplica a un metodo para que permita animaciones de interpolaciones. | source code
hacer_coordenada_mundo(x, y) Convierte una coordenada de pantalla a una coordenada dentro del motor de física. | source code
hacer_coordenada_pantalla_absoluta(x, y) | source code
listar_actores_en_consola() Imprime una lista de todos los actores en la escena sobre la consola. | source code
obtener_angulo_entre(punto_a, punto_b) Retorna el ángulo entro dos puntos de la pantalla. | source code
convertir_de_posicion_relativa_a_fisica(x, y) | source code
convertir_de_posicion_fisica_relativa(x, y) | source code
calcular_tiempo_en_recorrer(distancia_en_pixeles, velocidad) Calcula el tiempo que se tardará en recorrer una distancia en pixeles con una velocidad constante. | source code
interpolar(valor_o_valores, duracion=1, demora=0, tipo=`'``lineal``'`) Retorna un objeto que representa cambios de atributos progresivos. | source code
deneter_interpolacion(objeto, propiedad) Deteiene una interpolación iniciada en un campo de un objeto. | source code
obtener_area() Retorna el area que ocupa la ventana | source code
obtener_bordes() Retorna los bordes de la pantalla en forma de tupla. | source code
obtener_area_de_texto(texto) Informa el ancho y alto que necesitara un texto para imprimirse. | source code
realizar_pruebas() Imprime pruebas en pantalla para detectar si pilas tiene todas las dependencias instaladas. | source code
ver_codigo(objeto, imprimir, retornar) Imprime en pantalla el codigo fuente asociado a un objeto. | source code
obtener_uuid() Genera un identificador único. | source code
abrir_archivo_con_aplicacion_predeterminada(ruta_al_archivo) Intenta abrir un archivo con la herramienta recomenda por el sistema operativo. | source code
centrar_ventana(widget) Coloca la ventana o widget directamente en el centro del escritorio. | source code
descargar_archivo_desde_internet(parent, url, archivo_destino) Inicia la descarga de una archivo desde Internet. | source code
imprimir_todos_los_eventos() Muestra en consola los eventos activos y a quienes invocan | source code
habilitar_depuracion() Permite habilitar un breakpoint para depuracion una vez inicializado pilas. | source code
mostrar_mensaje_de_error_y_salir(motivo) Muestra un mensaje de error y termina con la ejecución de pilas. | source code
obtener_archivo_a_ejecutar_desde_argv() Obtiene la ruta del archivo a ejecutar desde la linea de argumentos del programa. | source code

Variables | [hide private]
| PATH = ``'``/Users/hugoruscitti/proyectos/pilas.git/pilas``'``
| __package__ = ``'``pilas``'``

Function Details | [hide private]

### es_interpolacion(an_object) | source code
Indica si un objeto se comportará como una interpolación. :param an_object: El objeto a consultar.

### obtener_ruta_al_recurso(ruta) | source code
Busca la ruta a un archivo de recursos. Los archivos de recursos (como las imagenes) se buscan en varios directorios (ver docstring de image.load), así que esta función intentará dar con el archivo en cuestión. :param ruta: Ruta al archivo (recurso) a inspeccionar.

### distancia(a, b) | source code
Retorna la distancia entre dos numeros.
    >>> distancia(30, 20)
    10
:param a: Un valor numérico. :param b: Un valor numérico.

### distancia_entre_dos_puntos((x1, y1), (x2, y2)) | source code
Retorna la distancia entre dos puntos en dos dimensiones. :param x1: Coordenada horizontal del primer punto. :param y1: Coordenada vertical del primer punto. :param x2: Coordenada horizontal del segundo punto. :param y2: Coordenada vertical del segundo punto.

### distancia_entre_dos_actores(a, b) | source code
Retorna la distancia en pixels entre dos actores. :param a: El primer actor. :param b: El segundo actor.

### actor_mas_cercano_al_actor(actor) | source code
Retorna el actor de la escena que esté mas cercano a otro indicado por parámetro. :param actor: El actor tomado como referencia.

### colisionan(a, b) | source code
Retorna True si dos actores estan en contacto. :param a: Un actor. :param b: El segundo actor a verificar.

### interpolable(f) | source code
Decorador que se aplica a un metodo para que permita animaciones de interpolaciones. Ejemplo:
       @interpolable
       def set_x(self, valor_x):
           [...]
:param f: Método sobre el que va a trabajar el interpolador.

### hacer_coordenada_mundo(x, y) | source code
Convierte una coordenada de pantalla a una coordenada dentro del motor de física. :param x: Coordenada horizontal. :param y: Coordenada vertical.

### obtener_angulo_entre(punto_a, punto_b) | source code
Retorna el ángulo entro dos puntos de la pantalla. :param punto_a: Una tupla con la coordenada del primer punto. :param punto_b: Una tupla con la coordenada del segundo punto.

### calcular_tiempo_en_recorrer(distancia_en_pixeles, velocidad) | source code
Calcula el tiempo que se tardará en recorrer una distancia en pixeles con una velocidad constante. :param distancia_en_pixeles: La longitud a recorrer medida en pixels. :param velocidad: La velocida medida en pixels.

### interpolar(valor_o_valores, duracion=1, demora=0, tipo=`'``lineal``'`) | source code
Retorna un objeto que representa cambios de atributos progresivos. El resultado de esta función se puede aplicar a varios atributos de los actores, por ejemplo:
    >>> bomba = pilas.actores.Bomba()
    >>> bomba.escala = pilas.interpolar(3)
Esta función también admite otros parámetros cómo: :param duracion: es la cantidad de segundos que demorará toda la interpolación. :param demora: cuantos segundos se deben esperar antes de iniciar. :param tipo: es el algoritmo de la interpolación, puede ser 'lineal'.

### deneter_interpolacion(objeto, propiedad) | source code
Deteiene una interpolación iniciada en un campo de un objeto.
    >>> pilas.utils.deneter_interpolacion(actor, 'y')
:param objeto: Actor del que se desea detener al interpolacion. :para propiedad: Cadena de texto que indica la propiedad del objeto cuya interpolación se desea terminar.

### obtener_area_de_texto(texto) | source code
Informa el ancho y alto que necesitara un texto para imprimirse. :param texto: La cadena de texto que se quiere imprimir.

### ver_codigo(objeto, imprimir, retornar) | source code
Imprime en pantalla el codigo fuente asociado a un objeto. :param objeto: El objeto que se quiere inspeccionar. :param imprimir: Un valor True o False indicando si se quiere imprimir directamente sobre la pantalla. :param retornar: Un valor True o False indicando si se quiere obtener el código como un string.

### abrir_archivo_con_aplicacion_predeterminada(ruta_al_archivo) | source code
Intenta abrir un archivo con la herramienta recomenda por el sistema operativo. :param ruta_al_archivo: La ruta al archivo que se quiere abrir.

### centrar_ventana(widget) | source code
Coloca la ventana o widget directamente en el centro del escritorio. :param widget: Widget que representa la ventana.

### descargar_archivo_desde_internet(parent, url, archivo_destino) | source code
Inicia la descarga de una archivo desde Internet. :param parent: El widget que será padre de la ventana. :param url: La URL desde donde se descargará el archivo. :param archivo_destino: La ruta en donde se guardará el archivo.

### mostrar_mensaje_de_error_y_salir(motivo) | source code
Muestra un mensaje de error y termina con la ejecución de pilas. :param motivo: Un mensaje que explica el problema o la razón del cierre de pilas.